TOKEN=$(cat /etc/hypernode/hypernode_api_token 2> /dev/null)
HNAPI_URL="https://api.hypernode.com/v2"
HEADERS="Authorization: Token $TOKEN"

_generate_completions() {
    case $COMP_CWORD in
        1)
            local COMPLETE_OPTIONS=$(_generate_systemctl_completion)
            local cur="${COMP_WORDS[COMP_CWORD]}"
            ;;
        2)
            local cur="${COMP_WORDS[COMP_CWORD]}"
            case ${COMP_WORDS[1]} in
              "settings") local COMPLETE_OPTIONS=$(_generate_settings_completion);;
              "show") local COMPLETE_OPTIONS=$(_generate_show_completion);;
              "whitelist") local COMPLETE_OPTIONS=$(_generate_whitelist_completion);;
              "block_attack") local COMPLETE_OPTIONS=$(_generate_blockattack_completion);;
              "preinstall") local COMPLETE_OPTIONS=$(_generate_preinstall_completion);;
              "attach_backup") local COMPLETE_OPTIONS=$(_generate_attach_backup_completion);;
            esac
            ;;
        3)
            local cur="${COMP_WORDS[COMP_CWORD]}"
            if [[ ${COMP_WORDS[1]} = "settings" ]]; then
                local COMPLETE_OPTIONS=$(_generate_settings_value_completion ${COMP_WORDS[2]})
                local cur="${COMP_WORDS[COMP_CWORD]}"
            fi
            if [[ ${COMP_WORDS[1]} = "whitelist" ]]; then
              case ${COMP_WORDS[2]} in
                "add") local COMPLETE_OPTIONS=$(_generate_whitelist_subcommand_completion);;
                "remove") local COMPLETE_OPTIONS=$(_generate_whitelist_subcommand_completion);;
                # Note: no autocompletion for `get` as this doesn't take any arguments
              esac
            fi
            ;;
        4)
    esac

    COMPREPLY=($(compgen -W "$COMPLETE_OPTIONS" -- "$cur"))
}

_generate_systemctl_completion() {
    local OPTIONS="settings show whitelist block_attack attach_backup list_backups create_backup preinstall"
    echo $OPTIONS
}

_generate_settings_completion() {
    local SETTINGS_JSON=$(curl -s $HNAPI_URL/app/eav_descriptions/ -H "$HEADERS")
    local OPTIONS=$(echo $SETTINGS_JSON | jq -r "keys[]")
    echo $OPTIONS
}

_generate_show_completion() {
    local OPTIONS="dkim_key"
    echo $OPTIONS
}

_generate_preinstall_completion() {
    local PREINSTALL_JSON=$(curl -s $HNAPI_URL/configuration/?allow_preinstall=true -H "$HEADERS")
    local OPTIONS=$(echo $PREINSTALL_JSON | jq -r ".results[].configuration_id")
    echo $OPTIONS
}

_generate_whitelist_completion() {
    local OPTIONS="add remove get"
    echo $OPTIONS
}

_generate_blockattack_completion() {
    local BLOCKATTACK_JSON=$(curl -s $HNAPI_URL/app/block_attack_descriptions/ -H "$HEADERS")
    local OPTIONS=$(echo $BLOCKATTACK_JSON | jq -r "keys[]")
    echo $OPTIONS
}

_generate_whitelist_subcommand_completion() {
    local OPTIONS="waf database ftp"
    echo $OPTIONS
}

_generate_attach_backup_completion() {
    local APP_NAME=$(jq -r '.tag' /etc/hypernode/app.json)
    local LISTBACKUPS_JSON=$(curl -s $HNAPI_URL/app/$APP_NAME/backup/ -H "$HEADERS")
    local OPTIONS=$(echo $LISTBACKUPS_JSON | jq -r ".results[].backup_id")
    echo $OPTIONS
}

_generate_settings_value_completion() {
    local SETTINGS_JSON=$(curl -s $HNAPI_URL/app/eav_descriptions/ -H "$HEADERS")
    # Check if value is an array or a constant. Only show multiple options
    if [[ $(echo "$SETTINGS_JSON" | jq -r ".$1[]" 2> /dev/null) ]]; then
      echo "$SETTINGS_JSON" | jq -r ".$1[]"
    fi
}

complete -F _generate_completions hypernode-systemctl
