from pwd import getpwall
from grp import getgrall

# UIDs for the following users: root = 0, toor = 0, app = 1000, support = 1002
UID_CHECKS = ["0", "1000", "1002"]


def gather_users_and_groups_information():
    """
    Gather all important information about the users and groups on a Hypernode.
    This is then put in a usable datastructure.
    :return: dict with all necessary information about the users and groups
    """
    all_users = getpwall()
    # Get ids from users to check
    uid_important = {}
    for uid in UID_CHECKS:
        uid_int = int(uid)
        selected_users = [user.pw_name for user in all_users if user.pw_uid == uid_int]
        uid_important[uid] = selected_users
    # Get user their name, home directory and shell
    users = [{'name': user.pw_name, 'dir': user.pw_dir, 'shell': user.pw_shell} for user in all_users]
    # Get group name and members
    groups = [{'name': group.gr_name, 'members': sorted(group.gr_mem)} for group in getgrall()]
    return {'uid_important': uid_important, 'users': users, 'groups': groups}
