"""
kamikaze3.metrics.long_processes
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
Provide metrics about long-running processes
"""

import sys
from os import EX_TEMPFAIL, EX_OK, EX_SOFTWARE
from logging import getLogger, DEBUG, INFO
from argparse import ArgumentParser
from kamikaze3.metrics.imageoptimizer_cron import gather_imageoptimizer_metrics
from kamikaze3.metrics.long_processes import gather_long_processes_metrics
from kamikaze3.metrics.web_requests import gather_web_requests_metrics
from kamikaze3.common.log import create_syslog_handler
from kamikaze3.common.csv import print_dicts_as_csv
from kamikaze3.longest_process_time.main import get_longest_process_time


program_name = 'hypernode-gather-metrics'
logger = getLogger(__name__)


def parse_args(args):
    parser = ArgumentParser(prog=program_name,
                            description='Provide metrics as CSV for consumption by telegraf')
    parser.add_argument('--verbose', action='store_true', help='print verbose messages to stderr')
    return parser.parse_args(args)


def main(args=None):
    """Program entry point, create a report of longest running processes:
    prints cvs of the duration of the longest-running MySQL query, shell PHP process, and fpm process, in seconds.

    :return: the exit code
    :rtype: int
    """

    opts = parse_args(args)

    logger.setLevel(DEBUG if opts.verbose else INFO)
    logger.addHandler(
        create_syslog_handler(
            name_override=program_name if __name__ == '__main__' else None
        )
    )

    try:
        result = {
            **gather_web_requests_metrics(),
            **gather_long_processes_metrics(),
            **gather_imageoptimizer_metrics()
        }
        print_dicts_as_csv([result])
        return EX_OK
    except KeyboardInterrupt:
        logger.warning('process interrupted by user')
        return EX_TEMPFAIL
    except Exception as err:
        logger.exception(err)
        return EX_SOFTWARE


if __name__ == '__main__':
    sys.exit(main())
