import logging
import os
from logging import handlers
from .settings import LOG_FILE

logger = logging.getLogger()
logger.setLevel(logging.INFO)
logger.propagate = False

# File
file_logformat = "%(asctime)s %(name)s %(levelname)s %(filename)s:%(lineno)s: %(message)s"
file_formatter = logging.Formatter(file_logformat)

# Console
stderr_logformat = "%(asctime)s %(name)s %(levelname)s %(message)s"
stderr_formatter = logging.Formatter(stderr_logformat)

# Do not add logging handlers when running in tests
if not os.environ.get('APP_ENV') == 'test':
    # Assign file handler here, to prevent permission denied errors
    try:
        file_handler = handlers.WatchedFileHandler(LOG_FILE)
        file_handler.setFormatter(file_formatter)
        file_handler.setLevel(logging.INFO)
        logger.addHandler(file_handler)
    except IOError:
        # This happens when user has no permissions for LOG_FILE
        print("NOTE: Unable to access log file {}".format(LOG_FILE))


def get_logger(name):
    """
    Simple syntactic helper function
    """
    return logging.getLogger(name)
