import argparse
from kamikaze3.mysqlbackup.exceptions import BrokenViewException, InvalidDatabaseNameException
from kamikaze3.mysqlbackup.mysqldumper import stream_new_backup_and_check_exit_codes
from kamikaze3.mysqlbackup.settings import DB_VALIDATION_REGEX
from kamikaze3.mysqlbackup.backupstate import BackupState
from .logger import get_logger
from .mysql import fetch_list_of_databases
from re import match
import sys

log = get_logger("hypernode.mysql.backup")
backupstate = BackupState()


def main():
    args = parse_arguments()
    exitcode = 0
    try:
        log.info("Starting database backup run")
        log.debug("Arguments used: {}".format(args))

        # Listify database name when --database flag is used
        if args.database:
            databases = [args.database]
        else:
            databases = fetch_list_of_databases()

        for db in databases:
            try:
                if match(DB_VALIDATION_REGEX, db):
                    stream_new_backup_and_check_exit_codes(database=db)
                    backupstate.backup_succeeded(db)
                else:
                    raise InvalidDatabaseNameException("Invalid character in database name found: {}".format(db))
            except (InvalidDatabaseNameException, BrokenViewException, Exception):
                exitcode = 1
                log.exception("Backup of database {} failed!".format(db))
        log.info("Finished database backup run")
    except Exception:
        log.exception('An error occurred during database backup')
        exitcode = 1

    backupstate.remove_obsolete_entries()
    sys.exit(exitcode)


def parse_arguments():
    """
    Parses script arguments from commandline into variables
    """

    parser = argparse.ArgumentParser()

    exclusive_group = parser.add_mutually_exclusive_group(required=True)
    exclusive_group.add_argument('-a', '--all', required=False, action='store_true',
                                 help="Create a backup of all databases on this host")
    exclusive_group.add_argument('-d', '--database', required=False, type=str,
                                 help="Provide a specific database to back up.")

    args = parser.parse_args()

    return args


if __name__ == '__main__':
    main()
