from kamikaze3.common.command import retry_on_exception
from .logger import get_logger
import MySQLdb

log = get_logger(__name__)


@retry_on_exception(max_retries=1)
def fetch_list_of_databases():
    """
    Fetches a list of all databases on the server,
    excluding Database|information_schema|performance_schema

    returns:
        List of all databases as strings
    """

    log.debug("Fetching lists of databases")
    excluded = ['information_schema', 'performance_schema']

    db = MySQLdb.connect(read_default_file="/root/.my.cnf")
    cur = db.cursor()
    cur.execute("show databases")
    databases = cur.fetchall()
    databases = [row[0] for row in databases if row[0] not in excluded]

    return databases
