import re

from kamikaze3.common.env import get_hn_app_var

NGINX_CONFIG_RELOAD_FLAG = '/data/web/nginx/_hvm_trigger_reload.flag'
NGINX_CONFIG_RELOADER_ERROR_FILE = '/data/web/nginx/nginx_error_output'

# Checksum
CHECKSUM_REGEX = r'(\w+)'  # Should this be stricter?
CHECKSUM_LINE_FORMAT = "# Hypernode Template Checksum: {checksum}\n"
CHECKSUM_COMPILED_PATTERN = re.compile(
    # Strictness is important!
    r'^{}$'.format(CHECKSUM_LINE_FORMAT.format(checksum=CHECKSUM_REGEX))
)
COMMENT_PATTERN = re.compile(r'^\s*#.*$')
EMPTY_LINE_PATTERN = re.compile(r'^\s*$')
LAST_TEMPLATE_MATCH_PATH = "/data/var/statefiles/matched_hmv_templates/{}"

# Importer
APPNAME_PATTERN = re.compile('\.?([a-z\d]+)\.hypernode\.io')
APP_IMPORT_BACKUP_DIR = '/data/web/.backup_nginx_configs/importerbackup_{timestamp}'
STATEFILE_IMPORT_BACKUP = '/data/web/.backup_nginx_configs/importerbackup_{timestamp}_statefile'

# Input
# Based on the Internationalized Domain Names Support by Oracle
# https://stackoverflow.com/a/26987741
VALID_SERVERNAME_REGEX = r'^(\*\.)?((xn--)?[a-z0-9.-])+\.(xn--)?[a-z0-9]+$'
SERVERNAME_PATTERN = re.compile(VALID_SERVERNAME_REGEX)

# List
PRINT_HEADERS = [
    'servername',
    'type',
    'default_server',
    'https',
    'force_https',
    'varnish',
    'ssl_config',
]

# Config locations
ROOT_SITES_DIR = '/etc/nginx/sites/'
HTTP_SITE_CONFIG = ROOT_SITES_DIR + 'http.{}.conf'
HTTPS_SITE_CONFIG = ROOT_SITES_DIR + 'https.{}.conf'
VARNISH_SITE_CONFIG = ROOT_SITES_DIR + 'varnish.{}.conf'
APP_NGINX_DIR = '/data/web/nginx/'
APP_SERVERNAME_DIR = APP_NGINX_DIR + '{}/'
APP_SSL_CERT_PATH = '/etc/nginx/app/ssl/{}.crtkeyca'
APP_HMV_BACKUP_DIR = '/data/web/.backup_nginx_configs/{configname}_{timestamp}/{configfile}'

# Template options
TEMPLATE_DIR = "/etc/hypernode/defaults/nginx/"
SERVERNAME_CONFIG_TEMPLATE_DIR = TEMPLATE_DIR + "servername_specific/"
TYPE_CONFIG_TEMPLATE_DIR = TEMPLATE_DIR + "servername_specific/{}/"
SITE_TEMPLATES = TEMPLATE_DIR + "sites/"

# Statefile
STATE_FILE_PATH = '/data/var/statefiles/nginx_vhosts.json'
DEFAULT_VHOST_OPTIONS = {
    'https': False,
    'varnish': False,
    'force_https': False,
    'port_http': 80,
    'port_https': 443,
    'port_http_staging': 8888,
    'port_https_staging': 8443,
    'ssl_config': 'modern' if get_hn_app_var('modern_ssl_config', 'enabled', default_val=False) else 'intermediate',
    'ssl_noclobber': False,
    'type': 'magento2',
    'ssl_cert_path': None,
    'default_server': False,
    'is_wildcard': False
}
TMP_ROOT_FILE = '/var/cache/managed_vhosts/tmp_file'
