import logging

from kamikaze3.systemctl.list_backups import list_backups
from kamikaze3.log.log import configure_logging
from kamikaze3.systemctl.block_attack import block_attack
from kamikaze3.systemctl.attach_backup import attach_backup
from kamikaze3.systemctl.create_backup import create_backup
from kamikaze3.systemctl.preinstall import preinstall
from kamikaze3.systemctl.parsing import parse_arguments
from kamikaze3.systemctl.settings import set_attribute, get_attribute
from kamikaze3.systemctl.show import show_attribute
from kamikaze3.systemctl.whitelist import add_whitelist_ip, remove_whitelist_ip, get_whitelists


logger = logging.getLogger(__name__)


def _handle_settings_arguments(args):
    if args.command == 'settings':
        if 'value' in args and args.value:
            set_attribute(args.attribute, args.value)
        else:
            get_attribute(args.attribute)


def _handle_show_arguments(args):
    if args.command == 'show':
        show_attribute(args.attribute)


def _handle_whitelist_arguments(args):
    if args.command == 'whitelist':
        _handle_whitelist_add(args)
        _handle_whitelist_remove(args)
        _handle_whitelist_get(args)


def _handle_block_attack_arguments(args):
    if args.command == 'block_attack':
        block_attack(args.attack_name)


def _handle_list_backups_arguments(args):
    if args.command == 'list_backups':
        list_backups()


def _handle_attach_backup_arguments(args):
    if args.command == 'attach_backup':
        backup_id = getattr(args, 'positional_backup_id', None) \
                or getattr(args, 'deprecated_backup_id', None)
        if getattr(args, 'deprecated_backup_id', None):
            logger.error(
                "The --backup-id option is deprecated. Please start using the positional "
                "argument instead: hypernode-systemctl attach_backup {}".format(backup_id)
            )
        attach_backup(backup_id=backup_id)


def _handle_create_backup_arguments(args):
    if args.command == 'create_backup':
        create_backup()


def _handle_preinstall_arguments(args):
    if args.command == 'preinstall':
        preinstall(args.preinstall_type, args.sample_data)


def _handle_whitelist_add(args):
    if args.whitelist_command == 'add':
        add_whitelist_ip(args.type, args.ip, vars(args).get('description', ''))


def _handle_whitelist_remove(args):
    if args.whitelist_command == 'remove':
        remove_whitelist_ip(args.type, args.ip)


def _handle_whitelist_get(args):
    if args.whitelist_command == 'get':
        get_whitelists(vars(args).get('type'))


def main(args=None):
    args = parse_arguments(args=args)
    configure_logging('kamikaze3', args.verbose)

    _handle_settings_arguments(args)
    _handle_show_arguments(args)
    _handle_whitelist_arguments(args)
    _handle_block_attack_arguments(args)
    _handle_attach_backup_arguments(args)
    _handle_list_backups_arguments(args)
    _handle_create_backup_arguments(args)
    _handle_preinstall_arguments(args)
