import requests
from kamikaze3.common.api import HYPERNODE_API_URL, get_hypernode_api_token, handle_api_response, SYSTEMCTL_USER_AGENT


def setup_preinstall_parsing(sub_parsers):
    allowed_preinstall_choices = get_allowed_preinstall_choices()
    if allowed_preinstall_choices:
        settings_usage = "hypernode-systemctl preinstall {} --sample-data".format(allowed_preinstall_choices[0])
    else:
        settings_usage = "Looks like we could not retrieve a valid set of pre-installs from our API. Please try " \
                         "again later."

    preinstall_parser = sub_parsers.add_parser('preinstall', usage=settings_usage)
    preinstall_parser.add_argument('preinstall_type', choices=allowed_preinstall_choices)
    preinstall_parser.add_argument(
        '--sample-data',
        help='Also install sample data (if available)',
        action='store_true',
        default=False
    )


def get_allowed_preinstall_choices():
    response = requests.get(
        HYPERNODE_API_URL + '/v2/configuration/?allow_preinstall=true',
        headers={'Authorization': 'Token {}'.format(get_hypernode_api_token()), 'User-Agent': SYSTEMCTL_USER_AGENT}
    )
    if handle_api_response(response):
        return [app_configuration['configuration_id'] for app_configuration in response.json()['results']]
    return []

